/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a kioslavenotifieradaptor -i kioslavenotifier.h -l Mollet::KioSlaveNotifier /usr/src/ports/kf5-kio-extras/kf5-kio-extras-17.04.3-1.x86_64/src/kio-extras-17.04.3/network/kded/org.kde.network.kioslavenotifier.xml
 *
 * qdbusxml2cpp is Copyright (C) 2016 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kioslavenotifieradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KioSlaveNotifierAdaptor
 */

KioSlaveNotifierAdaptor::KioSlaveNotifierAdaptor(Mollet::KioSlaveNotifier *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KioSlaveNotifierAdaptor::~KioSlaveNotifierAdaptor()
{
    // destructor
}

void KioSlaveNotifierAdaptor::onDirectoryEntered(const QString &dir)
{
    // handle method call org.kde.network.KioSlaveNotifier.onDirectoryEntered
    parent()->onDirectoryEntered(dir);
}

void KioSlaveNotifierAdaptor::onDirectoryLeft(const QString &dir)
{
    // handle method call org.kde.network.KioSlaveNotifier.onDirectoryLeft
    parent()->onDirectoryLeft(dir);
}

QStringList KioSlaveNotifierAdaptor::watchedDirectories()
{
    // handle method call org.kde.network.KioSlaveNotifier.watchedDirectories
    return parent()->watchedDirectories();
}


#include "kioslavenotifieradaptor.moc"
